summaryrefslogtreecommitdiff
path: root/services/surfaceflinger/Scheduler/Timer.h
diff options
context:
space:
mode:
Diffstat (limited to 'services/surfaceflinger/Scheduler/Timer.h')
-rw-r--r--services/surfaceflinger/Scheduler/Timer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/services/surfaceflinger/Scheduler/Timer.h b/services/surfaceflinger/Scheduler/Timer.h
index 69ce079437..a8e2d5a53d 100644
--- a/services/surfaceflinger/Scheduler/Timer.h
+++ b/services/surfaceflinger/Scheduler/Timer.h
@@ -30,9 +30,9 @@ public:
~Timer();
nsecs_t now() const final;
// NB: alarmAt and alarmCancel are threadsafe; with the last-returning function being effectual
// Most users will want to serialize thes calls so as to be aware of the timer state.
- void alarmAt(std::function<void()> const& cb, nsecs_t time) final;
+ void alarmIn(std::function<void()> const& cb, nsecs_t fireIn) final;
void alarmCancel() final;
void dump(std::string& result) const final;
@@ -30,9 +30,9 @@ public:
~Timer();
nsecs_t now() const final;
- // NB: alarmAt and alarmCancel are threadsafe; with the last-returning function being effectual
+ // NB: alarmIn and alarmCancel are threadsafe; with the last-returning function being effectual
// Most users will want to serialize thes calls so as to be aware of the timer state.